Summary: Utilities based around the yum package manager
Name: yum-utils
Version: 0.3.1
Release: 1.SL.2
License: GPL
Group: Development/Tools
Source: http://linux.duke.edu/yum/download/yum-utils/%{name}-%{version}.tar.gz
URL: http://linux.duke.edu/yum/download/yum-utils/
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildArch: noarch
Requires: python, yum >= 2.3.4

%description
yum-utils is a collection of utilities and examples for the yum package
manager. It includes utilities by different authors that make yum easier and 
more powerful to use.

%package -n yum-updateonboot
Summary: Run yum update on system boot
Group: System Environment/Base
Requires: python, yum >= 2.3.2
Requires(pre): chkconfig
Requires(post): chkconfig

%description -n yum-updateonboot
Runs yum update on system boot. This allows machines that have been turned
off for an extended amount of time to become secure immediately, instead of
waiting until the next early morning cron job.

%package -n yum-changelog
Summary: Yum plugin for viewing package changelogs before/after updating
Group: System Environment/Base
Requires: yum >= 2.3.4

%description -n yum-changelog
This plugin adds a command line option to allow viewing package changelog 
deltas before or after updating packages.

%package -n yum-fastestmirror
Summary: Yum plugin that sorts mirrorlist by connection speed
Group: System Environment/Base
Requires: yum >= 2.3.4

%description -n yum-fastestmirror
A plugin for Yum which sorts each repo's
mirrorlist by connection speed prior to downloading packages.

%package -n yum-fastestmirror-asyncore
Summary: Yum plugin that sorts mirrorlist by connection speed
Group: System Environment/Base
Requires: yum >= 2.3.4

%description -n yum-fastestmirror-asyncore
A plugin for Yum which sorts each repo's
mirrorlist by connection speed prior to downloading packages.

%package -n yum-fastestmirror-meta
Summary: Yum plugin that sorts mirrorlist by connection speed
Group: System Environment/Base
Requires: yum >= 2.3.4

%description -n yum-fastestmirror-meta
A variant of the fastestmirror plugin, but figures out the fastest
mirrors before metadata download which makes quite a difference
especially on large updates

%package -n yum-installonlyn
Summary: Yum plugin which only leaves n 'kernel' packages installed
Group: System Environment/Base
Requires: yum >= 2.3.4

%description -n yum-installonlyn
A plugin for yum which only leaves n 'kernel' packages installed instead
of infinitely doing installonly.
You can keep around more than just 2 kernels[2] by setting tokeep to
something in the plugin config file
Also, there's a caveat that we leave installed 2 of all variants...
eg, if you have kernel and kernel-smp, then the two most recent of both
will be left behind


%package -n yum-protectbase
Summary: Yum plugin for protecting certain repositories
Group: System Environment/Base
Requires: yum >= 2.3.4

%description -n yum-protectbase
This plugin allows certain repositories to be protected. Packages in the
protected repositories can't be overridden by packages in non-protected
repositories even if the non-protected repo has a later version.

This is mainly useful for preventing 3rd party repositories from interfering
with packages from base, updates, extras and livna.

%package -n yum-tsflags
Summary: Yum plugin for adding the tsflags functionality
Group: System Environment/Base
Requires: yum >= 2.3.4

%description -n yum-tsflags
This plugin adds a the tsflags functionality.

%package -n yum-versionlock
Summary: Yum plugin for locking packages to a certain version
Group: System Environment/Base
Requires: yum >= 2.3.4

%description -n yum-versionlock
This plugin prevents packages from getting upgraded beyond
given version.  The packages are defined in the file
/etc/yum/pluginconf.d/versionlock.list
The versionlist is in the format of 'rpm -qa'

%prep
%setup -q

%install
rm -rf $RPM_BUILD_ROOT
make DESTDIR=$RPM_BUILD_ROOT install
make -C updateonboot DESTDIR=$RPM_BUILD_ROOT install

# only changelog plugin for now...
# TD do fastestmirror, installonlyn, protectbase, versionlock, and tsflags
plugins="changelog fastestmirror installonlyn protectbase tsflags versionlock"
mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/yum/pluginconf.d/ $RPM_BUILD_ROOT/usr/lib/yum-plugins/

cd plugins
for plug in $plugins; do
    install -m 644 $plug/*.conf $RPM_BUILD_ROOT/%{_sysconfdir}/yum/pluginconf.d/
    install -m 644 $plug/*.py $RPM_BUILD_ROOT/usr/lib/yum-plugins/
done
# versionlock has an extra configuration file
install -m 644 versionlock/versionlock.list $RPM_BUILD_ROOT/%{_sysconfdir}/yum/pluginconf.d/
#%clean
#rm -rf $RPM_BUILD_ROOT

%post -n yum-updateonboot
/sbin/chkconfig --add yum-updateonboot >/dev/null 2>&1 || :;

%preun -n yum-updateonboot
if [ $1 = 0 ]; then
    /sbin/service yum-updateonboot stop >/dev/null 2>&1 || :;
    /sbin/chkconfig --del yum >/dev/null 2>&1 || :;
fi

%files
%defattr(-, root, root)
%doc README 
%doc COPYING
%doc plugins/
%{_bindir}/package-cleanup
%{_bindir}/repoclosure
%{_bindir}/repomanage
%{_bindir}/repoquery
%{_bindir}/repo-rss
%{_bindir}/yumdownloader
%{_bindir}/yum-builddep

%files -n yum-updateonboot
%defattr(-, root, root)
%doc updateonboot/README
%{_sysconfdir}/sysconfig/yum-updateonboot
%{_initrddir}/yum-updateonboot

%files -n yum-changelog
%defattr(-, root, root)
%{_sysconfdir}/yum/pluginconf.d/changelog.conf
/usr/lib/yum-plugins/changelog.py

%files -n yum-fastestmirror
%defattr(-, root, root)
%{_sysconfdir}/yum/pluginconf.d/fastestmirror.conf
/usr/lib/yum-plugins/fastestmirror.py

%files -n yum-fastestmirror-asyncore
%defattr(-, root, root)
%{_sysconfdir}/yum/pluginconf.d/fastestmirror-asyncore.conf
/usr/lib/yum-plugins/fastestmirror-asyncore.py

%files -n yum-fastestmirror-meta
%defattr(-, root, root)
%{_sysconfdir}/yum/pluginconf.d/fastestmirror-meta.conf
/usr/lib/yum-plugins/fastestmirror-meta.py

%files -n yum-installonlyn
%defattr(-, root, root)
%{_sysconfdir}/yum/pluginconf.d/installonlyn.conf
/usr/lib/yum-plugins/installonlyn.py

%files -n yum-protectbase
%defattr(-, root, root)
%{_sysconfdir}/yum/pluginconf.d/protectbase.conf
/usr/lib/yum-plugins/protectbase.py

%files -n yum-tsflags
%defattr(-, root, root)
%{_sysconfdir}/yum/pluginconf.d/tsflags.conf
/usr/lib/yum-plugins/tsflags.py

%files -n yum-versionlock
%defattr(-, root, root)
%{_sysconfdir}/yum/pluginconf.d/versionlock.conf
%{_sysconfdir}/yum/pluginconf.d/versionlock.list
/usr/lib/yum-plugins/versionlock.py

%changelog
* Fri Nov 18 2005 Panu Matilainen <pmatilai@laiskiainen.org> 0.3.1-1.SL.2
- created fastestmirror-asyncore from fastestmirror
- added fastestmirror-meta
- added installonlyn
- Gave a default configuration for versionlock

* Sat Sep 17 2005 Panu Matilainen <pmatilai@laiskiainen.org> 0.3.1-1.SL.1
- pulled out the fastestmirror, protectbase, tsflags, and versionlock to their
  own rpm's.

* Sat Sep 17 2005 Panu Matilainen <pmatilai@laiskiainen.org>
- version 0.3.1
- various enhancements and fixes to repoquery
- avoid tracebacks in yumex and pup when changelog plugin is enabled

* Mon Jul 25 2005 Panu Matilainen <pmatilai@laiskiainen.org>
- bump version to 0.3
- add yum-changelog subpackage
- add plugins as documentation to the main package
- require yum >= 2.3.4 (for getCacheDir)

* Tue Jun  21 2005 Gijs Hollestelle <gijs@gewis.nl>
- Added missing GPL COPYING file

* Wed Jun  1 2005 Seth Vidal <skvidal@phy.duke.edu>
- 0.2

* Mon May 23 2005 Panu Matilainen <pmatilai@laiskiainen.org>
- add yum-updateboot subpackage

* Mon May 16 2005 Gijs Hollestelle <gijs@gewis.nl>
- first version based on the mock spec file
